from nonebot.plugin import PluginMetadata

from .main import *  # noqa

__version__ = "0.3.5"
__plugin_meta__ = PluginMetadata(
    "HistoryBanner",
    "这是一个在机器人上获取原神历史卡池的插件",
    "XX历史卡池",
)